@@ -3,7 +3,5 @@ pub mod handler;
 #[derive(Debug, Clone)]
 pub enum IoEvent {
     Initialize,
-    Increment,
-    Decrement,
     LoadImage,
 }
